@@ -2,14 +2,14 @@ __author__ = "hugo.inzirillo"
 
 from abc import ABCMeta, abstractmethod
 
-from napoleontoolbox.napoleon_config_tools.parser import getter, config
+from napoleontoolbox.napoleon_config_tools import getter, config
 
 
-class AbsctractProvider(metaclass=ABCMeta):
+class AbsctractRessource(metaclass=ABCMeta):
 
     @property
     @abstractmethod
-    def key(self):
+    def id(self):
         raise NotImplemented
 
     @property
@@ -22,8 +22,6 @@ class AbsctractProvider(metaclass=ABCMeta):
     def type(self):
         raise NotImplemented
 
-
-class AbstractRessource(AbsctractProvider):
     @property
     @abstractmethod
     def user(self):
@@ -34,18 +32,19 @@ class AbstractRessource(AbsctractProvider):
     def password(self):
         raise NotImplemented
 
+
 @config
-class Service(AbstractRessource):
+class Service(AbsctractRessource):
     def __init__(self):
-        self.__key = None
+        self.__id = None
         self.__secret = None
         self.__type = None
         self.__user = None
         self.__password = None
 
     @property
-    def key(self):
-        return self.key
+    def id(self):
+        return self.id
 
     @property
     def secret(self):
@@ -63,10 +62,11 @@ class Service(AbstractRessource):
     def password(self):
         return self.password
 
+
 @config
-class Provider(AbsctractProvider):
+class Provider(AbsctractRessource):
     def __init__(self):
-        self.__key = None
+        self.__id = None
         self.__secret = None
         self.__type = None
 
@@ -74,24 +74,27 @@ class Provider(AbsctractProvider):
     def type(self):
         return self.type
 
-
     @property
-    def key(self):
-        return self.key
+    def id(self):
+        return self.id
 
     @property
     def secret(self):
         return self.secret
 
+    def user(self):
+        pass
 
+    def password(self):
+        pass
 
 
 class Bitmex(Provider):
 
     @property
-    @getter("providers.bitmex.key")
-    def key(self):
-        return self.key
+    @getter("providers.bitmex.id")
+    def id(self):
+        return self.id
 
     @property
     @getter("providers.bitmex.secret")
@@ -107,9 +110,9 @@ class Bitmex(Provider):
 class Dropbox(Provider):
 
     @property
-    @getter("providers.dropbox.key")
-    def key(self):
-        return self.key
+    @getter("providers.dropbox.id")
+    def id(self):
+        return self.id
 
     @property
     @getter("providers.dropbox.secret")
@@ -125,9 +128,9 @@ class Dropbox(Provider):
 class Binance(Provider):
 
     @property
-    @getter("providers.binance.key")
-    def key(self):
-        return self.key
+    @getter("providers.binance.id")
+    def id(self):
+        return self.id
 
     @property
     @getter("providers.binance.secret")
@@ -143,9 +146,9 @@ class Binance(Provider):
 class CryptoCompare(Provider):
 
     @property
-    @getter("providers.cryptocompare.key")
-    def key(self):
-        return self.key
+    @getter("providers.cryptocompare.id")
+    def id(self):
+        return self.id
 
     @property
     @getter("providers.cryptocompare.secret")
@@ -161,9 +164,9 @@ class CryptoCompare(Provider):
 class NapoleonService(Service):
 
     @property
-    @getter("providers.napoleon_service.key")
-    def key(self):
-        return self.key
+    @getter("providers.napoleon_service.id")
+    def id(self):
+        return self.id
 
     @property
     @getter("providers.napoleon_service.secret")
@@ -188,11 +191,11 @@ class NapoleonService(Service):
 
 class Ressources(object):
     def __init__(self):
-        self.__bitmex = Bitmex()
-        self.__binance = Binance()
-        self.__dropbox = Dropbox()
-        self.__cryptocompare = CryptoCompare()
-        self.__napoleon_service = NapoleonService()
+        self.__bitmex = Bitmex
+        self.__binance = Binance
+        self.__dropbox = Dropbox
+        self.__cryptocompare = CryptoCompare
+        self.__napoleon_service = NapoleonService
 
     @property
     def bitmex(self):
