@@ -595,7 +595,7 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
     except Exception as e:
         print(e)
 
-    bnb_rate = ohlc_bnb_min_binance.loc[start_time]['open_bnb_bnc']
+    bnb_rate = float(ohlc_bnb_min_binance.loc[start_time]['open_bnb_bnc'])
     initial_usd_balance = initial_usdt_balance + initial_bnb_balance * bnb_rate
     print(f'initial usdt balance {initial_usd_balance}')
 
